@@ -74,10 +74,10 @@ def build_venv(parser):
 
 
 def build_docker(parser):
-    venv_group = parser.add_argument_group('Docker container')
-    venv_group.add_argument('--docker-repo', help='image name without tag')
-    venv_group.add_argument('--docker-tag', help='image tag')
-    venv_group.add_argument('--docker-container', help='container name')
+    docker_group = parser.add_argument_group('Docker container')
+    docker_group.add_argument('--docker-repo', help='image name without tag')
+    docker_group.add_argument('--docker-tag', help='image tag')
+    docker_group.add_argument('--docker-container', help='container name')
 
 
 def build_other(parser):
