@@ -31,7 +31,7 @@ class PoetryConverter(BaseConverter):
             path = Path(path)
         if content:
             return '[tool.poetry]' in content
-        return path.name == 'pyproject.toml'
+        return path.name in ('poetry.toml', 'pyproject.toml')
 
     def loads(self, content) -> RootDependency:
         doc = tomlkit.parse(content)
@@ -223,6 +223,8 @@ class PoetryConverter(BaseConverter):
                 section['extras'] = tomlkit.table()
             # add new extras
             for extra, deps in extras.items():
+                if list(section['extras'].get(extra, [])) == deps:
+                    continue
                 section['extras'][extra] = deps
         elif 'extras' in section:
             # deop all old extras if there are no new extras
